@@ -66,14 +66,21 @@ class FakePathlibInitializationTest(RealPathlibTestCase):
             self.assertTrue(isinstance(path, self.pathlib.WindowsPath))
             self.assertTrue(isinstance(path, self.pathlib.PureWindowsPath))
             self.assertTrue(self.pathlib.PurePosixPath())
-            with self.assertRaises(NotImplementedError):
-                self.pathlib.PosixPath()
+            # in fake fs, we allow to use the other OS implementation
+            if self.use_real_fs():
+                with self.assertRaises(NotImplementedError):
+                    self.pathlib.PosixPath()
+            else:
+                self.assertTrue(self.pathlib.PosixPath())
         else:
             self.assertTrue(isinstance(path, self.pathlib.PosixPath))
             self.assertTrue(isinstance(path, self.pathlib.PurePosixPath))
             self.assertTrue(self.pathlib.PureWindowsPath())
-            with self.assertRaises(NotImplementedError):
-                self.pathlib.WindowsPath()
+            if self.use_real_fs():
+                with self.assertRaises(NotImplementedError):
+                    self.pathlib.WindowsPath()
+            else:
+                self.assertTrue(self.pathlib.WindowsPath())
 
     def test_init_with_segments(self):
         """Basic initialization tests - taken from pathlib.Path documentation
@@ -231,6 +238,13 @@ class FakePathlibPurePathTest(RealPathlibTestCase):
         with self.assertRaises(ValueError):
             self.path('passwd').relative_to('/usr')
 
+    @unittest.skipIf(sys.version_info < (3, 9) or pathlib2,
+                     'readlink new in Python 3.9')
+    def test_is_relative_to(self):
+        path = self.path('/etc/passwd')
+        self.assertTrue(path.is_relative_to('/etc'))
+        self.assertFalse(path.is_relative_to('/src'))
+
     def test_with_name(self):
         self.check_windows_only()
         self.assertEqual(
@@ -394,11 +408,10 @@ class FakePathlibFileObjectPropertyTest(RealPathlibTestCase):
         self.create_file(self.make_path('antoine', 'setup.py'))
         self.os.chdir(self.make_path('antoine'))
         # use real path to handle symlink /var to /private/var in MacOs
-        self.assertEqual(self.path().resolve(),
-                         self.path(
-                             self.os.path.realpath(
-                                 self.make_path('antoine'))))
-        self.assertEqual(
+        self.assert_equal_paths(self.path().resolve(),
+                                self.path(self.os.path.realpath(
+                                    self.make_path('antoine'))))
+        self.assert_equal_paths(
             self.path(
                 self.os.path.join('docs', '..', 'setup.py')).resolve(),
             self.path(
@@ -462,8 +475,8 @@ class FakePathlibFileObjectPropertyTest(RealPathlibTestCase):
         dir_path = self.make_path('jane')
         self.create_dir(dir_path)
         self.os.chdir(dir_path)
-        self.assertEqual(self.path.cwd(),
-                         self.path(self.os.path.realpath(dir_path)))
+        self.assert_equal_paths(self.path.cwd(),
+                                self.path(self.os.path.realpath(dir_path)))
 
     def test_expanduser(self):
         if is_windows:
@@ -477,13 +490,12 @@ class FakePathlibFileObjectPropertyTest(RealPathlibTestCase):
 
     def test_home(self):
         if is_windows:
-            self.assertEqual(self.path.home(),
-                             self.path(
-                                 os.environ['USERPROFILE'].replace('\\',
-                                                                   '/')))
+            self.assertEqual(self.path(
+                os.environ['USERPROFILE'].replace('\\', '/')),
+                self.path.home())
         else:
-            self.assertEqual(self.path.home(),
-                             self.path(os.environ['HOME']))
+            self.assertEqual(self.path(os.environ['HOME']),
+                             self.path.home())
 
 
 class RealPathlibFileObjectPropertyTest(FakePathlibFileObjectPropertyTest):
@@ -630,12 +642,45 @@ class FakePathlibPathFileOperationTest(RealPathlibTestCase):
         path = self.path(link_name)
         path.symlink_to(file_name)
         self.assertTrue(self.os.path.exists(link_name))
-        # file_obj = self.filesystem.ResolveObject(file_name)
-        # linked_file_obj = self.filesystem.ResolveObject(link_name)
-        # self.assertEqual(file_obj, linked_file_obj)
-        # link__obj = self.filesystem.LResolveObject(link_name)
         self.assertTrue(path.is_symlink())
 
+    @unittest.skipIf(sys.version_info < (3, 8) or pathlib2,
+                     'link_to new in Python 3.8')
+    def test_link_to(self):
+        self.skip_if_symlink_not_supported()
+        file_name = self.make_path('foo', 'bar.txt')
+        self.create_file(file_name)
+        self.assertEqual(1, self.os.stat(file_name).st_nlink)
+        link_name = self.make_path('link_to_bar')
+        path = self.path(file_name)
+        path.link_to(link_name)
+        self.assertTrue(self.os.path.exists(link_name))
+        self.assertFalse(path.is_symlink())
+        self.assertEqual(2, self.os.stat(file_name).st_nlink)
+
+    @unittest.skipIf(sys.version_info < (3, 8) or not pathlib2,
+                     'pathlib2 has no link_to')
+    def test_pathlib2_does_not_have_link_to(self):
+        self.skip_if_symlink_not_supported()
+        file_name = self.make_path('foo', 'bar.txt')
+        self.create_file(file_name)
+        self.assertEqual(1, self.os.stat(file_name).st_nlink)
+        link_name = self.make_path('link_to_bar')
+        path = self.path(file_name)
+        with self.assertRaises(AttributeError):
+            path.link_to(link_name)
+        self.assertFalse(self.os.path.exists(link_name))
+
+    @unittest.skipIf(sys.version_info < (3, 9) or pathlib2,
+                     'readlink new in Python 3.9')
+    def test_readlink(self):
+        self.skip_if_symlink_not_supported()
+        link_path = self.make_path('foo', 'bar', 'baz')
+        target = self.make_path('tarJAY')
+        self.create_symlink(link_path, target)
+        path = self.path(link_path)
+        self.assert_equal_paths(path.readlink(), self.path(target))
+
     def test_mkdir(self):
         dir_name = self.make_path('foo', 'bar')
         self.assert_raises_os_error(errno.ENOENT,
@@ -834,6 +879,12 @@ class FakePathlibUsageInOsFunctionsTest(RealPathlibTestCase):
         self.assertEqual(self.os.path.isfile(path),
                          self.os.path.isfile(self.path(path)))
 
+    def test_isfile_not_readable(self):
+        path = self.make_path('foo', 'bar', 'baz')
+        self.create_file(path, perm=0)
+        self.assertEqual(self.os.path.isfile(path),
+                         self.os.path.isfile(self.path(path)))
+
     def test_islink(self):
         path = self.make_path('foo', 'bar', 'baz')
         self.create_file(path)
@@ -862,7 +913,7 @@ class FakePathlibUsageInOsFunctionsTest(RealPathlibTestCase):
         self.create_dir(path)
         self.os.chdir(self.path(path))
         # use real path to handle symlink /var to /private/var in MacOs
-        self.assertEqual(self.os.path.realpath(path), self.os.getcwd())
+        self.assert_equal_paths(self.os.path.realpath(path), self.os.getcwd())
 
     def test_chmod(self):
         path = self.make_path('some_file')
@@ -973,6 +1024,13 @@ class FakePathlibUsageInOsFunctionsTest(RealPathlibTestCase):
         self.assertEqual(1, st.st_atime)
         self.assertEqual(2, st.st_mtime)
 
+    def test_truncate(self):
+        path = self.make_path('some_file')
+        self.create_file(path, contents='test_test')
+        self.os.truncate(self.path(path), length=4)
+        st = self.os.stat(path)
+        self.assertEqual(4, st.st_size)
+
 
 class RealPathlibUsageInOsFunctionsTest(FakePathlibUsageInOsFunctionsTest):
     def use_real_fs(self):
@@ -1039,4 +1097,4 @@ class FakeFilesystemPathLikeObjectTest(unittest.TestCase):
 
 
 if __name__ == '__main__':
-    unittest.main()
+    unittest.main(verbosity=2)
